@@ -13,6 +13,7 @@
 // #include the widget headers so that we can call the get_type() static methods:
 
 #include "embed.h"
+#include "viewport.h"
 
 extern "C"
 {
@@ -20,6 +21,7 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType gtk_clutter_embed_get_type(void);
+GType gtk_clutter_viewport_get_type(void);
 
 //Declarations of the *_error_quark() functions:
 
@@ -29,6 +31,7 @@ GType gtk_clutter_embed_get_type(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Clutter { namespace Gtk {  class Embed_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
+namespace Clutter { namespace Gtk {  class Viewport_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  } }
 
 namespace Clutter { namespace Gtk { 
 
@@ -38,9 +41,11 @@ void wrap_init()
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(gtk_clutter_embed_get_type(), &Clutter::Gtk::Embed_Class::wrap_new);
+  Glib::wrap_register(gtk_clutter_viewport_get_type(), &Clutter::Gtk::Viewport_Class::wrap_new);
 
   // Register the gtkmm gtypes:
   Clutter::Gtk::Embed::get_type();
+  Clutter::Gtk::Viewport::get_type();
 
 } // wrap_init()
 
