@@ -1,32 +1,33 @@
 /* Copyright (C) 1998-2006 The gtkmm Development Team
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Library General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
 #include "glibmm_generate_extra_defs/generate_extra_defs.h"
 #include <clutter/clutter.h>
-#include <clutter-gtk/gtk-clutter-embed.h>
+#include <clutter-gtk/clutter-gtk.h>
 #include <iostream>
 
-
-int main (int argc, char *argv[])
+int main(int argc, char** argv)
 {
-  clutter_init(&argc, &argv) ;
+  clutter_init(&argc, &argv);
 
-  std::cout 
-    << get_defs(GTK_TYPE_CLUTTER_EMBED)
+  std::cout
+    << get_defs(GTK_CLUTTER_TYPE_EMBED)
+    << get_defs(GTK_CLUTTER_TYPE_VIEWPORT)
+    << get_defs(GTK_CLUTTER_TYPE_SCROLLABLE)
     ;
 
   return 0;
